Terms of use (French version below)

By accessing Sakura (http://sakura.imag.fr/) for consultation or submission I have read the following and agree to respect it:

preliminary remarks.
Sakura is a web platform maintained by the Laboratoire d’Informatique de Grenoble which was initially supported by the Université Grenoble Alpes and the Centre National de la Recherche Scientifique. Sakura allows to capitalise processes and advertise research data. The goal of Sakura is to provide documented, reliable and stable contents, worflows, algorithms to take forward research.
The contents available on Sakura are subject to French laws (eg. Loi Informatique et Liberté in 1978, then 1991, 2004, and Règlement général sur la protection des données in 1995, then 2016) and must comply with the usual ethical rules occuring in 1) scientific research, 2) dissemination of contents on Internet and 3) use of services on Internet.

Contents.
The information, data collected about interaction between machines and users, analysis process and results of analyzes on these data saved on Sakura are deposits of owners and / or authors of theses contents. Authors and owners are identified as such on the platform. The dissemination of theses contents is organized by the platform with an access rights system to restrict access to such content. Default is public broadcasting, it is the preferred form for broadcasts. Restricted contents are listed on the platform but require a specific access grant from the owner for further operation. Private contents are hidden to all users except the owner and users whom the owner granted access. Users agree to respect the access rights system of the platform and not to engage in activity that could harm other users or corrupt contents.
Public contents on the platform may not be reposted or reused for commercial purposes or out of Sakura without the consent of the owners and / or authors of these contents.
Sakura does not ask any rights on the deposited contents except those necessary to preserve and disseminate these contents and can not be held responsible for their nature or substance.

Deposits of interaction data.
The interaction data deposits can be done for a limited broadcasting insofar as the restricted nature of the distribution is temporary and that eventually a public broadcasting via the platform will be adopted.
Anonymity for the users involved in the interactions recorded is the preferred form for interaction data available on Sakura. It must be sought before filing and respected by users of the platform during the consultation. Within the limits of the law Informatique et Liberté and for private data only, the anonymity of the users involved in the recorded interactions can be not fulfilled for a transitional phase leading to anonymous data replacing the original data.

Infrastructures.
Sakura can not guarantee the availability of content posted on forever, the non-regression, compatibility of access in case of changes. In case of suspected abnormality in the functioning of the platform, please, report on http://github.com/sakura-team/sakura
Sakura stores personal account information of its users and a history of performed activities and guarantees not to transmit it.

Conditions d’utilisation de Sakura ("Terms of use in French").

En accédant à Sakura (http://sakura.imag.fr/) pour consultation ou dépôt je reconnais avoir pris connaissance de ce qui suit et m’engage à le respecter :

Préliminaires.
Sakura est une plateforme web maintenue par le Laboratoire d’Informatique de Grenoble qui a été soutenue à sa création par l’Université Grenoble Alpes et le Centre National de la Recherche Scientifique. Sakura permet la conservation et la diffusion d’informations et de contenus de la recherche. L’objectif de Sakura est de fournir des contenus, données, algorithmes et processus d'analyse documentés, fiables et stables pour faire avancer la recherche.
Les contenus disponibles sur Sakura sont soumis aux lois françaises (ex. : Loi Informatique et Liberté de 1978, puis 1991, 2004, et Règlement général sur la protection des données de 1995, puis 2016 ) et doivent respecter les règles éthiques usuelles 1) de la recherche scientifique, 2) de la diffusion de contenus sur internet et 3) de l’utilisation de services sur internet.

Contenus.
Les informations, données d’interaction entre machines et utilisateurs, processus d’analyses et résultats d’analyses sur ces données conservés sur Sakura sont les dépôts de propriétaires et/ou auteurs de ces contenus. Auteurs et propriétaires sont identifiés comme tels sur la plateforme. La diffusion de ces contenus est organisée par la plateforme avec un système de droits d’accès permettant de limiter l’accès à ces contenus. Par défaut la diffusion est publique, c’est la forme privilégiée pour les diffusions. Des contenus à accès restreint sont listés sur la plateforme, toute action sur ces contenus nécessite une autorisation spécifique accordée par les propriétaires et/ou auteurs. Des contenus privés sont maintenu cachés sur la plateforme, seuls les propriétaires et/ou auteurs et les personnes à qui ces premiers ont donné des droits spécifiques peuvent y accéder. Le système de droits d’accès doit être respecté et les utilisateurs s'engagent à ne pas entreprendre d'actions qui pourraient porter atteinte aux autres utilisateurs ou corrompre les contenus de la plateforme.
Les contenus publiques diffusés sur la plateforme ne peuvent être rediffusés ou réutilisés à des fins commerciales ou hors Sakura sans l’accord des propriétaires et/ou auteurs de ces contenus.
Sakura ne demande aucun droit sur les contenus déposés sinon ceux nécessaires pour les conserver et les diffuser et ne peut être tenu responsable pour leur nature ou substance.

Dépots de données d’interaction.
Le dépôt de données d'interaction peut se faire pour une diffusion limitée dans la mesure où le caractère restreint de la diffusion est transitoire et qu’à terme une diffusion publique sur la plateforme soit adoptée.
L’anonymat des utilisateurs impliqués par les interactions enregistrées est à privilégier pour les données d’interaction disponibles sur Sakura. Il doit être recherché avant dépôt et respecté par les utilisateurs de la plateforme lors de la consultation. Dans les limites de la loi Informatique et Liberté et pour des données privées uniquement, l’anonymat des utilisateurs impliqués par les interactions enregistrées peut ne pas être respecté pour une phase transitoire de traitement des données menant à des données anonymes remplaçant les données initiales.

Infrastructures.
Sakura ne peut garantir la mise à disposition des contenus déposés ad vitam aeternam, la non régression, la compatibilité des accés en cas d’évolution. En cas d’anomalie suspectée dans le fonctionnement de la plateforme, le signaler sur http://github.com/sakura-team/sakura
Sakura conserve les informations personnelles des comptes de ses utilisateurs et un historique des activités effectuées et s’engage à ne pas les transmettre.